"""
Setup script for clipin package.
For modern installations, use pyproject.toml instead.
This file is kept for backward compatibility.
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
